Kiyotaka Nishibori License statement

2017-08-26 Thread Kiyotaka Nishibori
All of my past & future contributions to LibreOffice may be licensed 
under the MPLv2/LGPLv3+ dual license.


Kiyotaka Nishibori 

___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice-bugs] [Bug 60418] FILEOPEN and EDITING particular .odt with excessive lots of Comments causes heavy CPU and memory load , can crash on saving

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=60418

--- Comment #37 from waxma...@juno.com  ---
this process is absolutely useless to me. it is worse than useless, it is flat
out torture.
i am dyslexic. this format is completely unaccessible to me.
if you intend to be cruel and abusive to disabled people, don't give me access
to communicate the problems i have.

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 111409] Unify text direction functionality for all components

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=111409

--- Comment #2 from Volga  ---
We also need to compare related codes between the components.

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-commits] core.git: include/osl

2017-08-26 Thread Chris Sherlock
 include/osl/socket.h |  174 +++
 1 file changed, 94 insertions(+), 80 deletions(-)

New commits:
commit 1fab08fbeadc072f0196a7245785a6ab63474135
Author: Chris Sherlock 
Date:   Sun Aug 27 13:16:35 2017 +1000

osl: cleanup socket.h

Change-Id: I0f7889db570717e9606425b51a418c499bd3a40a

diff --git a/include/osl/socket.h b/include/osl/socket.h
index 796b3490223f..71a53da4282b 100644
--- a/include/osl/socket.h
+++ b/include/osl/socket.h
@@ -179,11 +179,11 @@ typedef enum {
 /** Common return codes of socket related functions.
  */
 typedef enum {
-osl_Socket_Ok,  /* successful completion */
-osl_Socket_Error,   /* error occurred, check osl_getLastSocketError() 
for details */
-osl_Socket_TimedOut,/* blocking operation timed out */
-osl_Socket_Interrupted, /* blocking operation was interrupted */
-osl_Socket_InProgress,  /* nonblocking operation is in progress */
+osl_Socket_Ok,  /* successful completion */
+osl_Socket_Error,   /* error occurred, check 
osl_getLastSocketError() for details */
+osl_Socket_TimedOut,/* blocking operation timed out */
+osl_Socket_Interrupted, /* blocking operation was interrupted */
+osl_Socket_InProgress,  /* nonblocking operation is in progress */
 osl_Socket_FORCE_EQUAL_SIZE = SAL_MAX_ENUM
 } oslSocketResult;
 
@@ -234,7 +234,7 @@ SAL_DLLPUBLIC oslSocketAddr SAL_CALL osl_resolveHostname(
 @param[in]  Port port number in host byte order.
 @retval 0 if address could not be created.
 */
-SAL_DLLPUBLIC oslSocketAddr SAL_CALL osl_createInetBroadcastAddr (
+SAL_DLLPUBLIC oslSocketAddr SAL_CALL osl_createInetBroadcastAddr(
 rtl_uString *strDottedAddr, sal_Int32 Port);
 
 
@@ -266,7 +266,7 @@ SAL_DLLPUBLIC sal_Int32 SAL_CALL osl_getServicePort(
 
 /** Retrieves the address-family from the Addr.
 @return the family of the socket-address.
-In case of an unknown family you get osl_Socket_FamilyInvalid.
+In case of an unknown family you get osl_Socket_FamilyInvalid.
 */
 SAL_DLLPUBLIC oslAddrFamily SAL_CALL osl_getFamilyOfSocketAddr(
 oslSocketAddr Addr);
@@ -274,7 +274,7 @@ SAL_DLLPUBLIC oslAddrFamily SAL_CALL 
osl_getFamilyOfSocketAddr(
 
 /** Retrieves the internet port-number of Addr.
 @return the port-number of the address in host-byte order. If Addr
-is not an address of type osl_Socket_FamilyInet, it returns 
OSL_INVALID_PORT
+is not an address of type osl_Socket_FamilyInet, it returns 
OSL_INVALID_PORT
 */
 SAL_DLLPUBLIC sal_Int32 SAL_CALL osl_getInetPortOfSocketAddr(
 oslSocketAddr Addr);
@@ -299,11 +299,12 @@ SAL_DLLPUBLIC oslSocketResult SAL_CALL 
osl_getHostnameOfSocketAddr(
 
 
 /** Gets the address in dotted decimal format.
+
 @param[in] Addr The socket address from which to extract the dotted 
decimal address.
 @param[out] strDottedInetAddr Contains the dotted decimal address
 (e.g. 141.99.20.34) represented by the address.
-If the address is invalid or not of type 
osl_Socket_FamilyInet,
-it returns 0.
+
+@retval If the address is invalid or not of type osl_Socket_FamilyInet, it 
returns 0.
 @retval osl_Socket_Ok
 @retval osl_Socket_Error
 */
@@ -402,14 +403,14 @@ typedef struct oslSocketImpl * oslSocket;
 
 /** increases the refcount of the socket handle by one
  */
-SAL_DLLPUBLIC void SAL_CALL osl_acquireSocket( oslSocket Socket );
+SAL_DLLPUBLIC void SAL_CALL osl_acquireSocket(oslSocket Socket);
 
 /** decreases the refcount of the socket handle by one.
 
 If the refcount drops to zero, the underlying socket handle
 is destroyed and becomes invalid.
  */
-SAL_DLLPUBLIC void SAL_CALL osl_releaseSocket( oslSocket Socket );
+SAL_DLLPUBLIC void SAL_CALL osl_releaseSocket(oslSocket Socket);
 
 /** Create a socket of the specified Family and Type. The semantic of
 the Protocol parameter depends on the given family and type.
@@ -417,9 +418,9 @@ SAL_DLLPUBLIC void SAL_CALL osl_releaseSocket( oslSocket 
Socket );
 to the allocated socket-datastructure.
 */
 SAL_DLLPUBLIC oslSocket SAL_CALL osl_createSocket(
-oslAddrFamily   Family,
-oslSocketType   Type,
-oslProtocol Protocol);
+oslAddrFamily Family,
+oslSocketType Type,
+oslProtocol Protocol);
 
 /** Retrieves the Address of the local end of the socket.
 Note that a socket must be bound or connected before
@@ -445,8 +446,8 @@ SAL_DLLPUBLIC oslSocketAddr SAL_CALL 
osl_getPeerAddrOfSocket(oslSocket Socket);
 @see osl_getLastSocketError()
 */
 SAL_DLLPUBLIC sal_Bool SAL_CALL osl_bindAddrToSocket(
-   oslSocket Socket,
-   oslSocketAddr Addr);
+   

[Libreoffice-commits] core.git: Branch 'private/tbsdy/workbench' - sal/Executable_setgetenv.mk sal/workben

2017-08-26 Thread Chris Sherlock
 sal/Executable_setgetenv.mk |2 +-
 1 file changed, 1 insertion(+), 1 deletion(-)

New commits:
commit cb71ba8e4d5e9a015b74d85623bebb7e3e0560e5
Author: Chris Sherlock 
Date:   Sun Aug 27 12:59:42 2017 +1000

sal workbench: more reorg cleanup

Change-Id: I9eba92b4d270e155d8017e67ae026cf6a73de4e7

diff --git a/sal/Executable_setgetenv.mk b/sal/Executable_setgetenv.mk
index 6aa4135f073e..f5a3a7e27143 100644
--- a/sal/Executable_setgetenv.mk
+++ b/sal/Executable_setgetenv.mk
@@ -23,7 +23,7 @@ $(eval $(call gb_Executable_use_libraries,setgetenv,\
 ))
 
 $(eval $(call gb_Executable_add_exception_objects,setgetenv,\
-sal/workben/osl/setgetenv \
+sal/workben/osl/process/setgetenv \
 ))
 
 $(call gb_Executable_get_clean_target,setgetenv) :
diff --git a/sal/workben/osl/setgetenv.cxx 
b/sal/workben/osl/process/setgetenv.cxx
similarity index 100%
rename from sal/workben/osl/setgetenv.cxx
rename to sal/workben/osl/process/setgetenv.cxx
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


New Defects reported by Coverity Scan for LibreOffice

2017-08-26 Thread scan-admin

Hi,

Please find the latest report on new defect(s) introduced to LibreOffice found 
with Coverity Scan.

4 new defect(s) introduced to LibreOffice found with Coverity Scan.
10 defect(s), reported by Coverity Scan earlier, were marked fixed in the 
recent build analyzed by Coverity Scan.

New defect(s) Reported-by: Coverity Scan
Showing 4 of 4 defect(s)


** CID 1416886:  Null pointer dereferences  (FORWARD_NULL)
/sw/qa/extras/ooxmlexport/ooxmlexport9.cxx: 1002 in 
testWatermarkLayer::verify()()



*** CID 1416886:  Null pointer dereferences  (FORWARD_NULL)
/sw/qa/extras/ooxmlexport/ooxmlexport9.cxx: 1002 in 
testWatermarkLayer::verify()()
996 }
997 
998 DECLARE_OOXMLEXPORT_TEST(testWatermarkLayer, "watermark-layer.docx")
999 {
1000 // Watermark was not visible if page background was set.
1001 
>>> CID 1416886:  Null pointer dereferences  (FORWARD_NULL)
>>> Assigning: "pTextDoc" = "dynamic_cast >> *>(this->mxComponent.get())".
1002 SwXTextDocument* pTextDoc = 
dynamic_cast(mxComponent.get());
1003 SdrPage* pPage = 
pTextDoc->GetDocShell()->GetDoc()->getIDocumentDrawModelAccess().GetDrawModel()->GetPage(0);
1004 SdrObject* pObject = pPage->GetObj(0);
1005 
1006 CPPUNIT_ASSERT(pObject);
1007 CPPUNIT_ASSERT_EQUAL(static_cast(1), 
pObject->GetLayer().get());

** CID 1416885:(NEGATIVE_RETURNS)



*** CID 1416885:(NEGATIVE_RETURNS)
/sc/source/ui/docshell/externalrefmgr.cxx: 2335 in 
ScExternalRefManager::getRangeNameTokensFromSrcDoc(unsigned short, const 
ScDocument *, rtl::OUString &)()
2329 switch (pToken->GetType())
2330 {
2331 case svSingleRef:
2332 {
2333 const ScSingleRefData& rRef = *pToken->GetSingleRef();
2334 OUString aTabName;
>>> CID 1416885:(NEGATIVE_RETURNS)
>>> "rRef->Tab()" is passed to a parameter that cannot be negative.
2335 pSrcDoc->GetName(rRef.Tab(), aTabName);
2336 ScExternalSingleRefToken aNewToken(nFileId, 
svl::SharedString( aTabName),   // string not interned
2337 *pToken->GetSingleRef());
2338 pNew->AddToken(aNewToken);
2339 bTokenAdded = true;
2340 }
/sc/source/ui/docshell/externalrefmgr.cxx: 2346 in 
ScExternalRefManager::getRangeNameTokensFromSrcDoc(unsigned short, const 
ScDocument *, rtl::OUString &)()
2340 }
2341 break;
2342 case svDoubleRef:
2343 {
2344 const ScSingleRefData& rRef = *pToken->GetSingleRef();
2345 OUString aTabName;
>>> CID 1416885:(NEGATIVE_RETURNS)
>>> "rRef->Tab()" is passed to a parameter that cannot be negative.
2346 pSrcDoc->GetName(rRef.Tab(), aTabName);
2347 ScExternalDoubleRefToken aNewToken(nFileId, 
svl::SharedString( aTabName),   // string not interned
2348 *pToken->GetDoubleRef());
2349 pNew->AddToken(aNewToken);
2350 bTokenAdded = true;
2351 }

** CID 1416884:  Memory - corruptions  (OVERRUN)



*** CID 1416884:  Memory - corruptions  (OVERRUN)
/toolkit/source/awt/vclxtoolkit.cxx: 1112 in 
::VCLXToolkit::ImplCreateWindow(VCLXWindow **, const 
com::sun::star::awt::WindowDescriptor &, vcl::Window *, long, MessBoxStyle)()
1106 if (xSystemDepParent.is())
1107 {
1108 sal_Int8 processID[16];
1109 
1110 rtl_getGlobalProcessId( 
reinterpret_cast(processID) );
 
>>> CID 1416884:  Memory - corruptions  (OVERRUN)
>>> Overrunning array "processID" of 2 8-byte elements by passing it to a 
>>> function which accesses it at element index 15 (byte offset 120) using 
>>> argument "16".
1112 css::uno::Sequence 
processIdSeq(processID, 16);
1113 
1114 css::uno::Any anyHandle = 
xSystemDepParent->getWindowHandle(processIdSeq, SYSTEM_DEPENDENT_TYPE);
1115 
1116 // use sal_Int64 here to accommodate 
all int types
1117 // uno::Any shift operator whill 
upcast if necessary

** CID 1416883:(USELESS_CALL)



*** CID 1416883:(USELESS_CALL)

CppCheck Report Update

2017-08-26 Thread cppcheck.libreoff...@gmail.com

A new cppcheck report is available at : 
http://dev-builds.libreoffice.org/cppcheck_reports/master/


Note:
The script generating this report was run at :
2017-27-08_03:26:13 with user buildslave at host vm140 as 
/home/buildslave/source/dev-tools/cppcheck/cppcheck-report.sh -s 
/home/buildslave/source/libo-core -c /home/buildslave/source/cppcheck -w 
/home/buildslave/tmp/www

It can be found and improved here:

https://gerrit.libreoffice.org/gitweb?p=dev-tools.git;a=blob;f=cppcheck/cppcheck-report.sh


___
LibreOffice mailing list
LibreOffice@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice


[Libreoffice-bugs] [Bug 112052] New: Comments in footnotes are lost in .doc and .docx files

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=112052

Bug ID: 112052
   Summary: Comments in footnotes are lost in .doc and .docx files
   Product: LibreOffice
   Version: 5.4.0.3 release
  Hardware: All
OS: All
Status: UNCONFIRMED
  Severity: normal
  Priority: medium
 Component: Writer
  Assignee: libreoffice-bugs@lists.freedesktop.org
  Reporter: cranberrydoug...@yahoo.com

Description:
Inserting comments (ctrl+alt+c) to leave notes works just fine with .odt files,
but comments in the footnotes of .doc and .docx formatted files are not saved.
Comments in the main body of text are properly saved.

Steps to Reproduce:
1. Open a .doc or .docx with footnotes.
2. Insert a comment in the footnote.
3. Save the file.

Actual Results:  
When the file is reopened, the comment is gone.

Expected Results:
When the file is reopened, the comment should have been saved and should be
visible.


Reproducible: Always

User Profile Reset: No

Additional Info:


User-Agent: Mozilla/5.0 (X11; Ubuntu; Linux x86_64; rv:55.0) Gecko/20100101
Firefox/55.0

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 80430] [META] LOCALHELP: Features x Documentation gap

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=80430

Adolfo Jayme  changed:

   What|Removed |Added

 Depends on|112015  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=112015
[Bug 112015] LOCALHELP Terminology change: "Spelling and Grammar" Renamed to
just "Spelling"
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 108890] UI: "Format" button in outline/ chapter numbering dialog not self-explanatory

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=108890

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 111846] Find & Replace: Rename diacritics and kashida search options

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=111846

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-ux-advise] [Bug 108891] Increase inter-line spacing for multiline text

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=108891

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are on the CC list for the bug.
___
Libreoffice-ux-advise mailing list
Libreoffice-ux-advise@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-ux-advise


[Libreoffice-bugs] [Bug 107996] FORMATTING: Watermark feature in page style dialog

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=107996

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 34689] UI scroll problem: Cell with dimensions exceeding screen dimensions impossible to work with

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=34689

Adolfo Jayme  changed:

   What|Removed |Added

Version|5.4.0.3 release |Inherited From OOo

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 108220] Add Character styles in Calc cells

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=108220

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 108634] Portable Windows version for a single pre-release of minor releases

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=108634

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 108555] Add line spacing feature to cell properties

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=108555

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 108817] Calc' s print preview starts at first page instead of page where user works

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=108817

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 108989] Add contextual UNO commands for name ranges and data validity to context menu

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=108989

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 107443] FILEOPEN: "Open" in "Document in Use" dialog for non-default file format documents opens read-only

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=107443

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-ux-advise] [Bug 111846] Find & Replace: Rename diacritics and kashida search options

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=111846

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are on the CC list for the bug.
___
Libreoffice-ux-advise mailing list
Libreoffice-ux-advise@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-ux-advise


[Libreoffice-bugs] [Bug 107763] Zooming in with Ctrl should intelligently keep selection in view or Ctrl+Shift should focus zoom on selection

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=107763

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 107120] New/update/ edit style commands only work with paragraph styles outside of the sidebar

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=107120

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 108891] Increase inter-line spacing for multiline text

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=108891

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 107479] Style "Text Body" can't be hidden

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=107479

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 107381] Default cell style colors shouldnt be included as document colors

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=107381

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 106876] [META] Find & Replace with styles

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=106876

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 106551] Means to rename stored custom colors

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=106551

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 106773] [META] Writer document canvas view jump issues

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=106773

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 106675] PRINTING: Add option to print without background

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=106675

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 106781] Addition of a style-focused formatting toolbar

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=106781

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-ux-advise] [Bug 107095] FORMATTING: Means to convert direct formatting into styles

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=107095

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are on the CC list for the bug.
___
Libreoffice-ux-advise mailing list
Libreoffice-ux-advise@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-ux-advise


[Libreoffice-bugs] [Bug 106556] Add functionality that highlights all directly formatted text

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=106556

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-ux-advise] [Bug 106551] Means to rename stored custom colors

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=106551

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are on the CC list for the bug.
___
Libreoffice-ux-advise mailing list
Libreoffice-ux-advise@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-ux-advise


[Libreoffice-bugs] [Bug 106502] VIEWING: Zooming in Page Preview goes to the first page, not where cursor is

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=106502

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 107095] FORMATTING: Means to convert direct formatting into styles

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=107095

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 106038] Selected range of text disappears when going to Print Preview and back

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=106038

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-ux-advise] [Bug 106781] Addition of a style-focused formatting toolbar

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=106781

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are on the CC list for the bug.
___
Libreoffice-ux-advise mailing list
Libreoffice-ux-advise@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-ux-advise


[Libreoffice-bugs] [Bug 105855] Some drop-down menus higher than others

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=105855

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 105863] Flicker when hovering over main menu with default rendering

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=105863

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 106375] "Center Horizontally" should be "Align Center" in Formatting toolbar

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=106375

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 106111] Display, PDF, print and print preview broken for all spreadsheets with line breaks, wrong scaling depending on zoom level (5.3 regression) ( steps in comment 40)

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=106111

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 106336] EDITING: Copying column to another one with different width doesn' t reposition image correctly

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=106336

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-ux-advise] [Bug 106556] Add functionality that highlights all directly formatted text

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=106556

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are on the CC list for the bug.
___
Libreoffice-ux-advise mailing list
Libreoffice-ux-advise@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-ux-advise


[Libreoffice-bugs] [Bug 105776] Writer page-down & page-up navigation in default single-page view

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=105776

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 106021] FORMATTING: Writer does not accept CSS box model for paragraphs

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=106021

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 103064] Introduce a comment style

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=103064

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 103733] [UI] Menus and toolbars of master documents have not been reorganized as for Writer documents

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=103733

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 105622] Highlight more than 64 cells in Calc

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=105622

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 102002] Redesign of the Load Styles dialog

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=102002

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 98544] Find & Replace dialog should remember the 'other options' state

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=98544

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-ux-advise] [Bug 103733] [UI] Menus and toolbars of master documents have not been reorganized as for Writer documents

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=103733

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are on the CC list for the bug.
___
Libreoffice-ux-advise mailing list
Libreoffice-ux-advise@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-ux-advise


[Libreoffice-bugs] [Bug 102157] DIALOG: Reset button doesnt reset values in paragraph style

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=102157

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 105225] Color palette cannot be chosen in various places

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=105225

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 94397] Little contrast in Styles and Formatting sidebar with background color

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=94397

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 84099] Calc can't handle very high rows

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=84099

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-ux-advise] [Bug 105225] Color palette cannot be chosen in various places

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=105225

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are on the CC list for the bug.
___
Libreoffice-ux-advise mailing list
Libreoffice-ux-advise@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-ux-advise


[Libreoffice-bugs] [Bug 86136] UI: Low contrast between active and inactive sheet tabs

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=86136

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 96532] Export of page with transparent PNG inserts gray line on transparency border

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=96532

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-ux-advise] [Bug 102002] Redesign of the Load Styles dialog

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=102002

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are on the CC list for the bug.
___
Libreoffice-ux-advise mailing list
Libreoffice-ux-advise@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-ux-advise


[Libreoffice-bugs] [Bug 87357] Contextual manage conditional formatting context menu entry

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=87357

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 80950] Styles & Formatting: Add 'Unused Styles' to style filter drop down

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=80950

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 83734] EDITING: Cropped image gets distorted when Compress Graphic is used

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=83734

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 62950] EDITING Add option to set default of pasting to ' paste text without formatting'

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=62950

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 64731] Feature Request - Make text selection for comments moveable / editable

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=64731

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 67770] CONFIGURATION: Sidebar customization settings not remembered after reopening

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=67770

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 64345] EDITING: Selected Area Disappeared When Switch WorkSheet

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=64345

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 49206] VIEWING: Tooltip for cell with partially hidden content

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=49206

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 62925] FORMATTING: enhancement: please add "chart styles" to the styles of Calc

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=62925

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 50699] Template Changer: Allow ability to change a document' s associated template

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=50699

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-ux-advise] [Bug 50699] Template Changer: Allow ability to change a document' s associated template

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=50699

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are on the CC list for the bug.
___
Libreoffice-ux-advise mailing list
Libreoffice-ux-advise@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-ux-advise


[Libreoffice-bugs] [Bug 38915] Multiple soffice.bin soffice.exe

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=38915

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 54068] The "Edit>Compare Documents" command does not detect changes in tables properly

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=54068

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-ux-advise] [Bug 49206] VIEWING: Tooltip for cell with partially hidden content

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=49206

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are on the CC list for the bug.
___
Libreoffice-ux-advise mailing list
Libreoffice-ux-advise@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-ux-advise


[Libreoffice-bugs] [Bug 47471] Clear Direct Formatting damages the document's styles

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=47471

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 36466] Copying Visible Cells Only

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=36466

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 49134] On opening a password-protected file, the LibreOffice window is not raised/given focus

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=49134

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 35176] Can't paste image from MS Office and other Windows Apps ( See Dupes)

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=35176

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 34689] UI scroll problem: Cell with dimensions exceeding screen dimensions impossible to work with

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=34689

Adolfo Jayme  changed:

   What|Removed |Added

 Blocks|111990  |


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=111990
[Bug 111990] UX and enhancement issues favored by Thomas.Lendo
-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 111990] UX and enhancement issues favored by Thomas.Lendo

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=111990

Adolfo Jayme  changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Depends on|34689, 35176, 36466, 38915, |
   |44282, 47471, 49134, 49206, |
   |50699, 54068, 62925, 62950, |
   |64345, 64731, 67770, 80950, |
   |83734, 84099, 86136, 87357, |
   |94397, 96532, 98544,|
   |102002, 102157, 103064, |
   |103733, 105225, 105622, |
   |105776, 105855, 105863, |
   |106021, 106038, 106111, |
   |106336, 106375, 106502, |
   |106551, 106556, 106675, |
   |106773, 106781, 106876, |
   |107095, 107120, 107381, |
   |107443, 107479, 107763, |
   |107996, 108220, 108555, |
   |108634, 108817, 108890, |
   |108891, 108989, 111846  |
 Resolution|--- |INVALID

--- Comment #4 from Adolfo Jayme  ---
This is pointless for QA purposes, so closing and removing dependencies. Please
don’t abuse metabugs.


Referenced Bugs:

https://bugs.documentfoundation.org/show_bug.cgi?id=34689
[Bug 34689] UI scroll problem: Cell with dimensions exceeding screen dimensions
impossible to work with
https://bugs.documentfoundation.org/show_bug.cgi?id=35176
[Bug 35176] Can't paste image from MS Office and other Windows Apps (See Dupes)
https://bugs.documentfoundation.org/show_bug.cgi?id=36466
[Bug 36466] Copying Visible Cells Only
https://bugs.documentfoundation.org/show_bug.cgi?id=38915
[Bug 38915] Multiple soffice.bin soffice.exe
https://bugs.documentfoundation.org/show_bug.cgi?id=44282
[Bug 44282] [FORMATING] [TOC] space missing between text and outline numbering
https://bugs.documentfoundation.org/show_bug.cgi?id=47471
[Bug 47471] Clear Direct Formatting damages the document's styles
https://bugs.documentfoundation.org/show_bug.cgi?id=49134
[Bug 49134] On opening a password-protected file, the LibreOffice window is not
raised/given focus
https://bugs.documentfoundation.org/show_bug.cgi?id=49206
[Bug 49206] VIEWING: Tooltip for cell with partially hidden content
https://bugs.documentfoundation.org/show_bug.cgi?id=50699
[Bug 50699] Template Changer: Allow ability to change a document's associated
template
https://bugs.documentfoundation.org/show_bug.cgi?id=54068
[Bug 54068] The "Edit>Compare Documents" command does not detect changes in
tables properly
https://bugs.documentfoundation.org/show_bug.cgi?id=62925
[Bug 62925] FORMATTING: enhancement: please add "chart styles" to the styles of
Calc
https://bugs.documentfoundation.org/show_bug.cgi?id=62950
[Bug 62950] EDITING Add option to set default of pasting to 'paste text without
formatting'
https://bugs.documentfoundation.org/show_bug.cgi?id=64345
[Bug 64345] EDITING: Selected Area Disappeared When Switch WorkSheet
https://bugs.documentfoundation.org/show_bug.cgi?id=64731
[Bug 64731] Feature Request - Make text selection for comments moveable /
editable
https://bugs.documentfoundation.org/show_bug.cgi?id=67770
[Bug 67770] CONFIGURATION: Sidebar customization settings not remembered after
reopening
https://bugs.documentfoundation.org/show_bug.cgi?id=80950
[Bug 80950] Styles & Formatting: Add 'Unused Styles' to style filter drop down
https://bugs.documentfoundation.org/show_bug.cgi?id=83734
[Bug 83734] EDITING: Cropped image gets distorted when Compress Graphic is used
https://bugs.documentfoundation.org/show_bug.cgi?id=84099
[Bug 84099] Calc can't handle very high rows
https://bugs.documentfoundation.org/show_bug.cgi?id=86136
[Bug 86136] UI: Low contrast between active and inactive sheet tabs
https://bugs.documentfoundation.org/show_bug.cgi?id=87357
[Bug 87357] Contextual manage conditional formatting context menu entry
https://bugs.documentfoundation.org/show_bug.cgi?id=94397
[Bug 94397] Little contrast in Styles and Formatting sidebar with background
color
https://bugs.documentfoundation.org/show_bug.cgi?id=96532
[Bug 96532] Export of page with transparent PNG inserts gray line on
transparency border
https://bugs.documentfoundation.org/show_bug.cgi?id=98544
[Bug 98544] Find & Replace dialog should remember the 'other options' state
https://bugs.documentfoundation.org/show_bug.cgi?id=102002
[Bug 102002] Redesign of the Load Styles dialog
https://bugs.documentfoundation.org/show_bug.cgi?id=102157
[Bug 102157] DIALOG: Reset button doesnt reset values in paragraph style
https://bugs.documentfoundation.org/show_bug.cgi?id=103064
[Bug 103064] Introduce a comment style
https://bugs.documentfoundation.org/show_bug.cgi?id=103733
[Bug 103733] [UI] Menus and toolbars of master documents have 

[Libreoffice-bugs] [Bug 64641] EDITING: Filtering in Mac-Addressbook is not possible

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=64641

--- Comment #19 from eisa01  ---
Still present

I click standard filter, select the "First" name field, select "like", type in
one of the first names in my address book, and nothing shows up

Version: 5.4.0.3
Build ID: 7556cbc6811c9d992f4064ab9287069087d7f62c
CPU threads: 2; OS: Mac OS X 10.12.6; UI render: default; 
Locale: en-US (en_US.UTF-8); Calc: group

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 111953] Start Center GUI no cross (recentdoc_remove.png) to delete unwanted recent documents in all themes except Human

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=111953

Adolfo Jayme  changed:

   What|Removed |Added

  Component|Writer  |UI

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 112050] I 855 401 6900 AOL customer service phone number AOL mail support number

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=112050

Regina Henschel  changed:

   What|Removed |Added

 Status|UNCONFIRMED |RESOLVED
  Component|General |deletionrequest
Version|1.13|unspecified
 Resolution|--- |INVALID
Product|cppunit |LibreOffice

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 112051] I 855 401 6900 facebook customer service phone number facebook mail support number

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=112051

Regina Henschel  changed:

   What|Removed |Added

 Status|UNCONFIRMED |RESOLVED
  Component|General |deletionrequest
Version|1.13|unspecified
 Resolution|--- |INVALID
Product|cppunit |LibreOffice

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 112042] idxf import filter not handling some text

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=112042

--- Comment #7 from V Stuart Foote  ---
Created attachment 135811
  --> https://bugs.documentfoundation.org/attachment.cgi?id=135811=edit
clip from DXF opened in CorelDraw 2017

in CorelDraw 2017 text annotation and mixed line types (dashed, solid) are
present.

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 64489] FILESAVE: LibreOffice produced .xls files don' t have file type info in properties when opened in Excel .doc files do

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=64489

eisa01  changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Resolution|--- |WORKSFORME

--- Comment #12 from eisa01  ---
When I open the .doc and .xls from the test file zip file, the properties show
for both documents on Office 2007 on Windows 7.

The screenshots in the test case file doesn't seem to be native Windows, so not
sure if that had something to do with the original issue?

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 64489] FILESAVE: LibreOffice produced .xls files don' t have file type info in properties when opened in Excel .doc files do

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=64489

--- Comment #11 from eisa01  ---
Created attachment 135810
  --> https://bugs.documentfoundation.org/attachment.cgi?id=135810=edit
Properties as shown in Office 2007 on Windows 7

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 86123] EDITING - Calc does not update cell display value from original boolean result calculation

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=86123

eisa01  changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Resolution|--- |WORKSFORME

--- Comment #8 from eisa01  ---
This has been fixed now

Setting a cell to 2 and 3, and equating shows FALSE. Editing to division shows
0.6667 as you would expect

Version: 5.4.0.3
Build ID: 7556cbc6811c9d992f4064ab9287069087d7f62c
CPU threads: 2; OS: Mac OS X 10.12.6; UI render: default; 
Locale: en-US (en_US.UTF-8); Calc: group

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 111989] libzmf: typo in Makefile -no-undefines -> -no-undefined

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=111989

Aron Budea  changed:

   What|Removed |Added

 Status|UNCONFIRMED |RESOLVED
 CC||ba...@caesar.elte.hu
 Resolution|--- |FIXED

--- Comment #1 from Aron Budea  ---
Seems fixed with this commit:
https://gerrit.libreoffice.org/gitweb?p=libzmf.git;a=commit;h=6be6f4b385323df34864a4c77586ad36487a1d31

Regardless, thanks for reporting. :)

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 86456] Libre Office corrupts boolean columns importing xlsx file

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=86456

eisa01  changed:

   What|Removed |Added

   See Also|https://www.libreoffice.org |https://bugs.documentfounda
   |/bugzilla/show_bug.cgi?id=8 |tion.org/show_bug.cgi?id=81
   |1350|350
 OS|Mac OS X (All)  |All

--- Comment #8 from eisa01  ---
The third row is no longer corrupted, but LibreOffice shows 0/1 with
=FALSE()/TRUE(), so this may just be a presentation issue now?

This is both present on Mac and Windows

It could be a duplicate of bug 81350

Version: 5.4.0.3
Build ID: 7556cbc6811c9d992f4064ab9287069087d7f62c
CPU threads: 2; OS: Mac OS X 10.12.6; UI render: default; 
Locale: en-US (en_US.UTF-8); Calc: group

Version: 5.4.0.3 (x64)
Build ID: 7556cbc6811c9d992f4064ab9287069087d7f62c
CPU threads: 1; OS: Windows 6.1; UI render: default; 
Locale: en-US (en_US); Calc: group

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 81350] FILEOPEN: XLSX file: boolean values imported wrongly, consecutive values hidden

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=81350

eisa01  changed:

   What|Removed |Added

   See Also||https://bugs.documentfounda
   ||tion.org/show_bug.cgi?id=86
   ||456

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 112042] idxf import filter not handling some text

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=112042

--- Comment #6 from V Stuart Foote  ---
Created attachment 135809
  --> https://bugs.documentfoundation.org/attachment.cgi?id=135809=edit
clip of DXF opened with defaults in AutoDesk 2016

Also, the LO rendering from 3.3.0 -> 6.0.0alpha1+ picks up most of the
dimension lines as dashed, rather than solid as IrfanView (BabaCAD4Image
plugin). 

Have to check again what CorelDraw 2017 seemed the labeling was more complete
than with the AutoDesk 2016 clip.

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-commits] core.git: sc/qa sc/source

2017-08-26 Thread serdarot5
 sc/qa/unit/data/xlsx/tdf83672.xlsx   |binary
 sc/qa/unit/subsequent_filters-test.cxx   |   21 +
 sc/source/filter/oox/drawingfragment.cxx |6 +++---
 3 files changed, 24 insertions(+), 3 deletions(-)

New commits:
commit 2b7561799eeb0bf8ae14bff3702ffa6cda15d17c
Author: serdarot5 
Date:   Sat Aug 5 21:11:22 2017 +0300

fixed image and textbox rotation on xlsx files tdf#83672

Change-Id: If91e64e46601e1f8b5834d278f14182f8c949a2b
Reviewed-on: https://gerrit.libreoffice.org/40790
Tested-by: Jenkins 
Reviewed-by: Markus Mohrhard 

diff --git a/sc/qa/unit/data/xlsx/tdf83672.xlsx 
b/sc/qa/unit/data/xlsx/tdf83672.xlsx
new file mode 100755
index ..0469682b2f43
Binary files /dev/null and b/sc/qa/unit/data/xlsx/tdf83672.xlsx differ
diff --git a/sc/qa/unit/subsequent_filters-test.cxx 
b/sc/qa/unit/subsequent_filters-test.cxx
index 66873628055a..43c0664e5245 100644
--- a/sc/qa/unit/subsequent_filters-test.cxx
+++ b/sc/qa/unit/subsequent_filters-test.cxx
@@ -241,6 +241,7 @@ public:
 void testTdf100709XLSX();
 void testTdf97598XLSX();
 void testTdf110440XLSX();
+void testTdf83672XLSX();
 
 void testPageScalingXLSX();
 void testActiveXCheckboxXLSX();
@@ -369,6 +370,7 @@ public:
 CPPUNIT_TEST(testTdf100709XLSX);
 CPPUNIT_TEST(testTdf97598XLSX);
 CPPUNIT_TEST(testTdf110440XLSX);
+CPPUNIT_TEST(testTdf83672XLSX);
 
 CPPUNIT_TEST(testPageScalingXLSX);
 CPPUNIT_TEST(testActiveXCheckboxXLSX);
@@ -3929,6 +3931,25 @@ void ScFiltersTest::testTdf97598XLSX()
 xDocSh->DoClose();
 }
 
+void ScFiltersTest::testTdf83672XLSX()
+{
+ScDocShellRef xDocSh = loadDoc("tdf83672.", FORMAT_XLSX);
+CPPUNIT_ASSERT_MESSAGE("Failed to load tdf83672.xlsx", xDocSh.is());
+uno::Reference< drawing::XDrawPagesSupplier > xDoc(
+xDocSh->GetModel(), uno::UNO_QUERY_THROW );
+uno::Reference< drawing::XDrawPage > xPage(
+xDoc->getDrawPages()->getByIndex(0), uno::UNO_QUERY_THROW );
+uno::Reference< drawing::XShape > xShape(
+xPage->getByIndex(0), uno::UNO_QUERY_THROW );
+CPPUNIT_ASSERT_MESSAGE( "failed to load shape", xShape.is() );
+uno::Reference< beans::XPropertySet > xShapeProperties(
+xShape, uno::UNO_QUERY );
+sal_Int32 nRotate = 0;
+xShapeProperties->getPropertyValue("RotateAngle") >>= nRotate;
+CPPUNIT_ASSERT(nRotate != 0);
+xDocSh->DoClose();
+}
+
 #ifdef UNX
 void ScFiltersTest::testUnicodeFileNameGnumeric()
 {
diff --git a/sc/source/filter/oox/drawingfragment.cxx 
b/sc/source/filter/oox/drawingfragment.cxx
index 9675067d168b..555a3fe5f14f 100644
--- a/sc/source/filter/oox/drawingfragment.cxx
+++ b/sc/source/filter/oox/drawingfragment.cxx
@@ -257,9 +257,9 @@ void DrawingFragment::onEndElement()
 if( mxDrawPage.is() && mxShape.get() && mxAnchor.get() )
 {
 // Rotation is decided by orientation of shape determined
-// by the anchor position given by 'twoCellAnchor'
-if ( getCurrentElement() == XDR_TOKEN( twoCellAnchor ) )
-mxShape->setRotation(0);
+// by the anchor position given by 'editAs="oneCell"'
+if ( mxAnchor->getEditAs() != ShapeAnchor::ANCHOR_ONECELL )
+mxShape->setRotation(0);
 EmuRectangle aShapeRectEmu = mxAnchor->calcAnchorRectEmu( 
getDrawPageSize() );
 const bool bIsShapeVisible = mxAnchor->isAnchorValid();
 if( (aShapeRectEmu.X >= 0) && (aShapeRectEmu.Y >= 0) && 
(aShapeRectEmu.Width >= 0) && (aShapeRectEmu.Height >= 0) )
___
Libreoffice-commits mailing list
libreoffice-comm...@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-commits


[Libreoffice-bugs] [Bug 112013] impossible to run V5.35 after install; impossible to save file in V5.4 ==> crash

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=112013

Aron Budea  changed:

   What|Removed |Added

 CC||ba...@caesar.elte.hu

--- Comment #1 from Aron Budea  ---
Is this Windows XP, and if it is, do you have SP3 installed, which is the
minimal requirement?

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 59163] FILESAVE: Mac proxy icon isn' t displayed after first saving a document

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=59163

eisa01  changed:

   What|Removed |Added

 CC||pinert...@gmail.com

--- Comment #6 from eisa01  ---
*** Bug 84301 has been marked as a duplicate of this bug. ***

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 84301] Mac OS X: Command-click on document window title does nothing on newly saved documents

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=84301

eisa01  changed:

   What|Removed |Added

 Status|NEW |RESOLVED
 Resolution|--- |DUPLICATE

--- Comment #13 from eisa01  ---
This is really a duplicate of bug 59163, as the drop down is tied to the proxy
icon

The drop down (i.e. the proxy icon) shows if you save an empty document, but if
you have written e.g., test it doesn't show

Version: 5.4.0.3
Build ID: 7556cbc6811c9d992f4064ab9287069087d7f62c
CPU threads: 2; OS: Mac OS X 10.12.6; UI render: default; 
Locale: en-US (en_US.UTF-8); Calc: group

*** This bug has been marked as a duplicate of bug 59163 ***

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 59163] FILESAVE: Mac proxy icon isn' t displayed after first saving a document

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=59163

eisa01  changed:

   What|Removed |Added

 Status|RESOLVED|NEW
 Resolution|WORKSFORME  |---

--- Comment #5 from eisa01  ---
While testing bug 84301 I discovered that if I save a new document with
contents (e.g., write Test in Writer) the proxy icon doesn't show, so this has
not been (fully) fixed after all

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 112042] idxf import filter not handling some text

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=112042

V Stuart Foote  changed:

   What|Removed |Added

Version|5.4.0.3 release |Inherited From OOo

--- Comment #5 from V Stuart Foote  ---
Just checked a Windows 3.3.0 build
LibreOffice 3.3.0 
OOO330m19 (Build:6)
tag libreoffice-3.3.0.4

Text was already missing at this point, so inherited from OOo.

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 112042] idxf import filter not handling some text

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=112042

V Stuart Foote  changed:

   What|Removed |Added

 Status|NEEDINFO|NEW

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


[Libreoffice-bugs] [Bug 112042] idxf import filter not handling some text

2017-08-26 Thread bugzilla-daemon
https://bugs.documentfoundation.org/show_bug.cgi?id=112042

--- Comment #4 from V Stuart Foote  ---
Created attachment 135808
  --> https://bugs.documentfoundation.org/attachment.cgi?id=135808=edit
DXF opened in Irfanview, showing Text annotation

-- 
You are receiving this mail because:
You are the assignee for the bug.___
Libreoffice-bugs mailing list
Libreoffice-bugs@lists.freedesktop.org
https://lists.freedesktop.org/mailman/listinfo/libreoffice-bugs


  1   2   3   >